@@ -12,7 +12,7 @@ closedir(DIR);
 open(IN, "$htpath/style/Crystal/$size/html-menu-treeview/Crystal.css") or die ": $!";
 
 while(my $line = <IN>) {
-        if($line =~ /td\.(folder.+)Closed{/) {
+        if($line =~ /td\.(folder.+)Closed/) {
                 my $classname = $1;
                 my $img       = shift @lines;
                 $img = shift @lines while($img =~ /^\..*/);
@@ -32,13 +32,18 @@ Style("Crystal");
 size($size);
 clasic(1) if(defined param('clasic'));
 my $zoom =
-  '<a href="./crystal.pl?style=Crystal&amp;size=16" class="treeviewLink">16</a>|<a href="./crystal.pl?style=Crystal&amp;size=22" class="treeviewLink" >22</a>|<a href="./crystal.pl?style=Crystal&amp;size=32" class="treeviewLink">32</a>|<a href="./crystal.pl?style=Crystal&amp;size=48" class="treeviewLink">48</a>|<a href="./crystal.pl?style=Crystal&amp;size=64" class="treeviewLink">64</a>|<a href="./crystal.pl?style=Crystal&amp;size=128" class="treeviewLink">128</a>';
+a({-href=>'./crystal.pl?style=Crystal&amp;size=16',-class => "treeviewLink$size"},'16').'&#160;|&#160;'.
+a({-href=>'./crystal.pl?style=Crystal&amp;size=22',-class => "treeviewLink$size"},'22').'&#160;|&#160;'.
+a({-href=>'./crystal.pl?style=Crystal&amp;size=32',-class => "treeviewLink$size"},'32').'&#160;|&#160;'.
+a({-href=>'./crystal.pl?style=Crystal&amp;size=48',-class => "treeviewLink$size"},'48').'&#160;|&#160;'.
+a({-href=>'./crystal.pl?style=Crystal&amp;size=64',-class => "treeviewLink$size"},'64').'&#160;|&#160;'.
+a({-href=>'./crystal.pl?style=Crystal&amp;size=64',-class => "treeviewLink$size"},'128');
 print header(),
 start_html(
 	-title => 'Crystal',
 	-script => jscript() . preload(),
 	-style => {-code => css()}
 ),
-"$zoom<br/>",
+"$zoom",br(),
 Tree(\@tree),
 end_html;
\ No newline at end of file
